pro ssw_fs_maskdbase, dbindex, dbdata, omask, $
   cat=cat, darkstuff=darkstuff, diskstuff=diskstuff, $
   rnum=rnum, rlevel=rlevel

;+
;   Name: ssw_fs_maskdbase
;
;   Purpose: return desired subsets of the findstuff region/blob dbase
;
;   Input Parameters:
;      dbindex,dbdata - index,data from dbase (FITS) file(s) / 3D OK
;
;   Keyword Parameters:
;      cat - optional catalog entry to match
;      rnum - return mask for this region number
;      rlevel - return subset of regions of this level
;               original region numbering is preserved
;
;
;   Calling Sequence:
;      ssw_fs_maskdbase, dbindex, dbdata,omask, [OPTIONS]
;
;   Calling Example:
;
;      (explicit dbase file list or as derived from catalog search)
;
;      IDL> mreadfits,dbasefiles,dbindex,dbdata       
;      IDL> ssw_fs_maskdbase,dbindex,dbdata,mask,rlevel=0  
;           This call masks/returns the data which falls in 
;           the "first level" - see the following tags in DBINDEX
;           IDL> help,dbindex,/str
;           (...)
;   INFILE          STRING    'crb_dc_AM_512_19911110_153557.fits' ; INPUT FILE
;   LOWCUT          STRING    '1,16,100,1000'        ; lower threshold
;   HICUT           STRING    '15,99,1001,50000'     ; uper threshold
;   RLIMITS         STRING    '0,64,128,192'         ; boundries
;  
; The above dbase contains 4 sets of regions:
;
;    Count-Range    Region#(pixel values)
;    Low   Hi   
;     1    15       0   - 63        Note that for each level, pixel values
;    16    99       64  - 127       equal to the boundries (0,64,128,192)
;   100  1000       128 - 191       indicate all pixels which are NOT a 
;  1001  (N/A)      192 - 255       member of any region in that level.
;      
;
;   History:
;      31-August-2001 - S.L.Freeland
;- 
;       

dblow=str2arr(gt_tagval(dbindex,/lowcut))
dbhi =str2arr(gt_tagval(dbindex,/hicut))
dblim=str2arr(gt_tagval(dbindex,/rlimits))

if data_chk(cat,/struct) then begin 
   rnum=gt_tagval(cat,/rnum,missing=-1)
endif

case 1 of 
   n_elements(rnum) gt 0: omask=dbdata eq rnum
   n_elements(rlevel) gt 0: begin 
      if rlevel lt 0 or rlevel gt n_elements(dblow)-1 then $ 
        box_message,'requested level (' + strtrim(rlevel,2) + ') is out of range
      lev=rlevel>0<(n_elements(dblow)-1)
      tlim=[dblim,256]
      omask=dbdata*(dbdata gt tlim(lev) and dbdata lt tlim(lev+1))
   endcase
endcase

return
end

